Color.ANSI.ParseError exception
(Color v0.4.0)
Raised when Color.ANSI.parse/1 cannot interpret an ANSI SGR
escape sequence.
Has fields:
:sequence— the offending input binary.:reason— a short atom describing the failure::no_csi— the input does not start withESC [.:no_terminator— the sequence has no closingm.:no_colour_param— the sequence has a CSI and terminator but no colour parameter (e.g.\e[0mreset,\e[1mbold,\e[39mdefault-foreground).:bad_index— a 256-colour index (38;5;N) is out of range or not a valid integer.:bad_rgb— a truecolor R/G/B triple is out of range or not valid integers.